@@ -22,6 +22,14 @@ templates = (
   ('DerivativeImageFilter', 'itk::DerivativeImageFilter', 'itkDerivativeImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
   ('DerivativeImageFilter', 'itk::DerivativeImageFilter', 'itkDerivativeImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('DerivativeImageFilter', 'itk::DerivativeImageFilter', 'itkDerivativeImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
+  ('DiscreteGaussianDerivativeImageFilter', 'itk::DiscreteGaussianDerivativeImageFilter', 'itkDiscreteGaussianDerivativeImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
+  ('DiscreteGaussianDerivativeImageFilter', 'itk::DiscreteGaussianDerivativeImageFilter', 'itkDiscreteGaussianDerivativeImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
+  ('DiscreteGaussianDerivativeImageFilter', 'itk::DiscreteGaussianDerivativeImageFilter', 'itkDiscreteGaussianDerivativeImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
+  ('DiscreteGaussianDerivativeImageFilter', 'itk::DiscreteGaussianDerivativeImageFilter', 'itkDiscreteGaussianDerivativeImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
+  ('DiscreteGaussianDerivativeImageFilter', 'itk::DiscreteGaussianDerivativeImageFilter', 'itkDiscreteGaussianDerivativeImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
+  ('DiscreteGaussianDerivativeImageFilter', 'itk::DiscreteGaussianDerivativeImageFilter', 'itkDiscreteGaussianDerivativeImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
+  ('DiscreteGaussianDerivativeImageFilter', 'itk::DiscreteGaussianDerivativeImageFilter', 'itkDiscreteGaussianDerivativeImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
+  ('DiscreteGaussianDerivativeImageFilter', 'itk::DiscreteGaussianDerivativeImageFilter', 'itkDiscreteGaussianDerivativeImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
   ('GradientVectorFlowImageFilter', 'itk::GradientVectorFlowImageFilter', 'itkGradientVectorFlowImageFilterIVF22IVF22F', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >, float'),
   ('GradientVectorFlowImageFilter', 'itk::GradientVectorFlowImageFilter', 'itkGradientVectorFlowImageFilterICVF22ICVF22F', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >, float'),
   ('GradientVectorFlowImageFilter', 'itk::GradientVectorFlowImageFilter', 'itkGradientVectorFlowImageFilterIVF33IVF33F', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >, float'),
@@ -38,7 +46,10 @@ templates = (
   ('HessianToObjectnessMeasureImageFilter', 'itk::HessianToObjectnessMeasureImageFilter', 'itkHessianToObjectnessMeasureImageFilterISSRTD33IUC3', True, 'itk::Image< itk::SymmetricSecondRankTensor< double, 3 >, 3 >, itk::Image< unsigned char,3 >'),
   ('HessianToObjectnessMeasureImageFilter', 'itk::HessianToObjectnessMeasureImageFilter', 'itkHessianToObjectnessMeasureImageFilterISSRTD33IUS3', True, 'itk::Image< itk::SymmetricSecondRankTensor< double, 3 >, 3 >, itk::Image< unsigned short,3 >'),
   ('HessianToObjectnessMeasureImageFilter', 'itk::HessianToObjectnessMeasureImageFilter', 'itkHessianToObjectnessMeasureImageFilterISSRTD33IF3', True, 'itk::Image< itk::SymmetricSecondRankTensor< double, 3 >, 3 >, itk::Image< float,3 >'),
-  ('HoughTransform2DCirclesImageFilter', 'itk::HoughTransform2DCirclesImageFilter', 'itkHoughTransform2DCirclesImageFilterFF', True, 'float, float'),
+  ('HoughTransform2DCirclesImageFilter', 'itk::HoughTransform2DCirclesImageFilter', 'itkHoughTransform2DCirclesImageFilterSSULF', True, 'signed short, unsigned long, float'),
+  ('HoughTransform2DCirclesImageFilter', 'itk::HoughTransform2DCirclesImageFilter', 'itkHoughTransform2DCirclesImageFilterUCULF', True, 'unsigned char, unsigned long, float'),
+  ('HoughTransform2DCirclesImageFilter', 'itk::HoughTransform2DCirclesImageFilter', 'itkHoughTransform2DCirclesImageFilterUSULF', True, 'unsigned short, unsigned long, float'),
+  ('HoughTransform2DCirclesImageFilter', 'itk::HoughTransform2DCirclesImageFilter', 'itkHoughTransform2DCirclesImageFilterFULF', True, 'float, unsigned long, float'),
   ('HoughTransform2DLinesImageFilter', 'itk::HoughTransform2DLinesImageFilter', 'itkHoughTransform2DLinesImageFilterFF', True, 'float, float'),
   ('LaplacianImageFilter', 'itk::LaplacianImageFilter', 'itkLaplacianImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('LaplacianImageFilter', 'itk::LaplacianImageFilter', 'itkLaplacianImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
@@ -59,6 +70,14 @@ templates = (
   ('LaplacianSharpeningImageFilter', 'itk::LaplacianSharpeningImageFilter', 'itkLaplacianSharpeningImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('LaplacianSharpeningImageFilter', 'itk::LaplacianSharpeningImageFilter', 'itkLaplacianSharpeningImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
   ('MaskFeaturePointSelectionFilter', 'itk::MaskFeaturePointSelectionFilter', 'itkMaskFeaturePointSelectionFilterIF3', True, 'itk::Image< float,3 >'),
+  ('MultiScaleHessianBasedMeasureImageFilter', 'itk::MultiScaleHessianBasedMeasureImageFilter', 'itkMultiScaleHessianBasedMeasureImageFilterISS2ISSRTD22ISS2', True, 'itk::Image< signed short,2 >, itk::Image< itk::SymmetricSecondRankTensor< double, 2 >, 2 >, itk::Image< signed short,2 >'),
+  ('MultiScaleHessianBasedMeasureImageFilter', 'itk::MultiScaleHessianBasedMeasureImageFilter', 'itkMultiScaleHessianBasedMeasureImageFilterIUC2ISSRTD22IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< itk::SymmetricSecondRankTensor< double, 2 >, 2 >, itk::Image< unsigned char,2 >'),
+  ('MultiScaleHessianBasedMeasureImageFilter', 'itk::MultiScaleHessianBasedMeasureImageFilter', 'itkMultiScaleHessianBasedMeasureImageFilterIUS2ISSRTD22IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< itk::SymmetricSecondRankTensor< double, 2 >, 2 >, itk::Image< unsigned short,2 >'),
+  ('MultiScaleHessianBasedMeasureImageFilter', 'itk::MultiScaleHessianBasedMeasureImageFilter', 'itkMultiScaleHessianBasedMeasureImageFilterIF2ISSRTD22IF2', True, 'itk::Image< float,2 >, itk::Image< itk::SymmetricSecondRankTensor< double, 2 >, 2 >, itk::Image< float,2 >'),
+  ('MultiScaleHessianBasedMeasureImageFilter', 'itk::MultiScaleHessianBasedMeasureImageFilter', 'itkMultiScaleHessianBasedMeasureImageFilterISS3ISSRTD33ISS3', True, 'itk::Image< signed short,3 >, itk::Image< itk::SymmetricSecondRankTensor< double, 3 >, 3 >, itk::Image< signed short,3 >'),
+  ('MultiScaleHessianBasedMeasureImageFilter', 'itk::MultiScaleHessianBasedMeasureImageFilter', 'itkMultiScaleHessianBasedMeasureImageFilterIUC3ISSRTD33IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< itk::SymmetricSecondRankTensor< double, 3 >, 3 >, itk::Image< unsigned char,3 >'),
+  ('MultiScaleHessianBasedMeasureImageFilter', 'itk::MultiScaleHessianBasedMeasureImageFilter', 'itkMultiScaleHessianBasedMeasureImageFilterIUS3ISSRTD33IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< itk::SymmetricSecondRankTensor< double, 3 >, 3 >, itk::Image< unsigned short,3 >'),
+  ('MultiScaleHessianBasedMeasureImageFilter', 'itk::MultiScaleHessianBasedMeasureImageFilter', 'itkMultiScaleHessianBasedMeasureImageFilterIF3ISSRTD33IF3', True, 'itk::Image< float,3 >, itk::Image< itk::SymmetricSecondRankTensor< double, 3 >, 3 >, itk::Image< float,3 >'),
   ('SimpleContourExtractorImageFilter', 'itk::SimpleContourExtractorImageFilter', 'itkSimpleContourExtractorImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
   ('SimpleContourExtractorImageFilter', 'itk::SimpleContourExtractorImageFilter', 'itkSimpleContourExtractorImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
   ('SimpleContourExtractorImageFilter', 'itk::SimpleContourExtractorImageFilter', 'itkSimpleContourExtractorImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
@@ -84,3 +103,4 @@ templates = (
   ('ZeroCrossingImageFilter', 'itk::ZeroCrossingImageFilter', 'itkZeroCrossingImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('ZeroCrossingImageFilter', 'itk::ZeroCrossingImageFilter', 'itkZeroCrossingImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
 )
+snake_case_functions = ('laplacian_image_filter', 'zero_crossing_based_edge_detection_image_filter', 'derivative_image_filter', 'canny_edge_detection_image_filter', 'mask_feature_point_selection_filter', 'hessian3_d_to_vesselness_measure_image_filter', 'multi_scale_hessian_based_measure_image_filter', 'hessian_to_objectness_measure_image_filter', 'hough_transform2_d_circles_image_filter', 'sobel_edge_detection_image_filter', 'hessian_recursive_gaussian_image_filter', 'bilateral_image_filter', 'simple_contour_extractor_image_filter', 'discrete_gaussian_derivative_image_filter', 'mesh_source', 'gradient_vector_flow_image_filter', 'laplacian_sharpening_image_filter', 'unsharp_mask_image_filter', 'image_to_mesh_filter', 'zero_crossing_image_filter', 'laplacian_recursive_gaussian_image_filter', 'hough_transform2_d_lines_image_filter', )
