@@ -315,12 +315,6 @@ templates = (
   ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIUC2IUC3', True, 'itk::Image< unsigned char,2 >,itk::Image< unsigned char,3 >'),
   ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIUS2IUS3', True, 'itk::Image< unsigned short,2 >,itk::Image< unsigned short,3 >'),
   ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIF2IF3', True, 'itk::Image< float,2 >,itk::Image< float,3 >'),
-  ('VectorResampleImageFilter', 'itk::VectorResampleImageFilter', 'itkVectorResampleImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
-  ('VectorResampleImageFilter', 'itk::VectorResampleImageFilter', 'itkVectorResampleImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
-  ('VectorResampleImageFilter', 'itk::VectorResampleImageFilter', 'itkVectorResampleImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
-  ('VectorResampleImageFilter', 'itk::VectorResampleImageFilter', 'itkVectorResampleImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
-  ('VectorResampleImageFilter', 'itk::VectorResampleImageFilter', 'itkVectorResampleImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
-  ('VectorResampleImageFilter', 'itk::VectorResampleImageFilter', 'itkVectorResampleImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
   ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS2ISS2IVF22', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
   ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS3ISS3IVF23', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
   ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS2ISS2IVF32', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
@@ -398,3 +392,4 @@ templates = (
   ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
   ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
 )
+snake_case_functions = ('permute_axes_image_filter', 'warp_image_filter', 'interpolate_image_filter', 'flip_image_filter', 'shrink_image_filter', 'orient_image_filter', 'b_spline_upsample_image_filter', 'wrap_pad_image_filter', 'zero_flux_neumann_pad_image_filter', 'paste_image_filter', 'resample_image_filter', 'mirror_pad_image_filter', 'b_spline_resample_image_filter_base', 'slice_by_slice_image_filter', 'pad_image_filter', 'cyclic_shift_image_filter', 'region_of_interest_image_filter', 'b_spline_downsample_image_filter', 'tile_image_filter', 'bin_shrink_image_filter', 'change_information_image_filter', 'constant_pad_image_filter', 'crop_image_filter', 'expand_image_filter', 'pad_image_filter_base', )
